# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class OctoprintProgress(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'completion': 'float',
        'filepos': 'int',
        'print_time': 'int',
        'print_time_left': 'int',
        'print_time_origin': 'str'
    }

    attribute_map = {
        'completion': 'completion',
        'filepos': 'filepos',
        'print_time': 'printTime',
        'print_time_left': 'printTimeLeft',
        'print_time_origin': 'printTimeOrigin'
    }

    def __init__(self, completion=None, filepos=None, print_time=None, print_time_left=None, print_time_origin=None, local_vars_configuration=None):  # noqa: E501
        """OctoprintProgress - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._completion = None
        self._filepos = None
        self._print_time = None
        self._print_time_left = None
        self._print_time_origin = None
        self.discriminator = None

        self.completion = completion
        self.filepos = filepos
        self.print_time = print_time
        self.print_time_left = print_time_left
        self.print_time_origin = print_time_origin

    @property
    def completion(self):
        """Gets the completion of this OctoprintProgress.  # noqa: E501


        :return: The completion of this OctoprintProgress.  # noqa: E501
        :rtype: float
        """
        return self._completion

    @completion.setter
    def completion(self, completion):
        """Sets the completion of this OctoprintProgress.


        :param completion: The completion of this OctoprintProgress.  # noqa: E501
        :type completion: float
        """

        self._completion = completion

    @property
    def filepos(self):
        """Gets the filepos of this OctoprintProgress.  # noqa: E501


        :return: The filepos of this OctoprintProgress.  # noqa: E501
        :rtype: int
        """
        return self._filepos

    @filepos.setter
    def filepos(self, filepos):
        """Sets the filepos of this OctoprintProgress.


        :param filepos: The filepos of this OctoprintProgress.  # noqa: E501
        :type filepos: int
        """

        self._filepos = filepos

    @property
    def print_time(self):
        """Gets the print_time of this OctoprintProgress.  # noqa: E501


        :return: The print_time of this OctoprintProgress.  # noqa: E501
        :rtype: int
        """
        return self._print_time

    @print_time.setter
    def print_time(self, print_time):
        """Sets the print_time of this OctoprintProgress.


        :param print_time: The print_time of this OctoprintProgress.  # noqa: E501
        :type print_time: int
        """

        self._print_time = print_time

    @property
    def print_time_left(self):
        """Gets the print_time_left of this OctoprintProgress.  # noqa: E501


        :return: The print_time_left of this OctoprintProgress.  # noqa: E501
        :rtype: int
        """
        return self._print_time_left

    @print_time_left.setter
    def print_time_left(self, print_time_left):
        """Sets the print_time_left of this OctoprintProgress.


        :param print_time_left: The print_time_left of this OctoprintProgress.  # noqa: E501
        :type print_time_left: int
        """

        self._print_time_left = print_time_left

    @property
    def print_time_origin(self):
        """Gets the print_time_origin of this OctoprintProgress.  # noqa: E501


        :return: The print_time_origin of this OctoprintProgress.  # noqa: E501
        :rtype: str
        """
        return self._print_time_origin

    @print_time_origin.setter
    def print_time_origin(self, print_time_origin):
        """Sets the print_time_origin of this OctoprintProgress.


        :param print_time_origin: The print_time_origin of this OctoprintProgress.  # noqa: E501
        :type print_time_origin: str
        """

        self._print_time_origin = print_time_origin

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OctoprintProgress):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OctoprintProgress):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import printnanny_api_client
from printnanny_api_client.api.users_api import UsersApi  # noqa: E501
from printnanny_api_client.rest import ApiException


class TestUsersApi(unittest.TestCase):
    """UsersApi unit test stubs"""

    def setUp(self):
        self.api = printnanny_api_client.api.users_api.UsersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_users_me_retrieve(self):
        """Test case for users_me_retrieve

        """
        pass

    def test_users_partial_update(self):
        """Test case for users_partial_update

        """
        pass

    def test_users_retrieve(self):
        """Test case for users_retrieve

        """
        pass

    def test_users_update(self):
        """Test case for users_update

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class PatchedAlertRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'octoprint_device': 'int',
        'event_type': 'AlertEventTypeEnum',
        'seen': 'bool',
        'sent': 'bool'
    }

    attribute_map = {
        'octoprint_device': 'octoprint_device',
        'event_type': 'event_type',
        'seen': 'seen',
        'sent': 'sent'
    }

    def __init__(self, octoprint_device=None, event_type=None, seen=None, sent=None, local_vars_configuration=None):  # noqa: E501
        """PatchedAlertRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._octoprint_device = None
        self._event_type = None
        self._seen = None
        self._sent = None
        self.discriminator = None

        self.octoprint_device = octoprint_device
        self.event_type = event_type
        if seen is not None:
            self.seen = seen
        if sent is not None:
            self.sent = sent

    @property
    def octoprint_device(self):
        """Gets the octoprint_device of this PatchedAlertRequest.  # noqa: E501


        :return: The octoprint_device of this PatchedAlertRequest.  # noqa: E501
        :rtype: int
        """
        return self._octoprint_device

    @octoprint_device.setter
    def octoprint_device(self, octoprint_device):
        """Sets the octoprint_device of this PatchedAlertRequest.


        :param octoprint_device: The octoprint_device of this PatchedAlertRequest.  # noqa: E501
        :type octoprint_device: int
        """

        self._octoprint_device = octoprint_device

    @property
    def event_type(self):
        """Gets the event_type of this PatchedAlertRequest.  # noqa: E501


        :return: The event_type of this PatchedAlertRequest.  # noqa: E501
        :rtype: AlertEventTypeEnum
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """Sets the event_type of this PatchedAlertRequest.


        :param event_type: The event_type of this PatchedAlertRequest.  # noqa: E501
        :type event_type: AlertEventTypeEnum
        """

        self._event_type = event_type

    @property
    def seen(self):
        """Gets the seen of this PatchedAlertRequest.  # noqa: E501


        :return: The seen of this PatchedAlertRequest.  # noqa: E501
        :rtype: bool
        """
        return self._seen

    @seen.setter
    def seen(self, seen):
        """Sets the seen of this PatchedAlertRequest.


        :param seen: The seen of this PatchedAlertRequest.  # noqa: E501
        :type seen: bool
        """

        self._seen = seen

    @property
    def sent(self):
        """Gets the sent of this PatchedAlertRequest.  # noqa: E501


        :return: The sent of this PatchedAlertRequest.  # noqa: E501
        :rtype: bool
        """
        return self._sent

    @sent.setter
    def sent(self, sent):
        """Sets the sent of this PatchedAlertRequest.


        :param sent: The sent of this PatchedAlertRequest.  # noqa: E501
        :type sent: bool
        """

        self._sent = sent

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PatchedAlertRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PatchedAlertRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.telemetry_event_polymorphic import TelemetryEventPolymorphic  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestTelemetryEventPolymorphic(unittest.TestCase):
    """TelemetryEventPolymorphic unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTelemetryEventPolymorphic(self):
        """Test TelemetryEventPolymorphic"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
